/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.mirror.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Each item in the user's timeline is represented as a TimelineItem JSON structure, described
 * below.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Mirror API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class TimelineItem extends GenericJson {

  /**
   * A list of media attachments associated with this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Attachment> attachments;

  static {
    // hack to force ProGuard to consider Attachment used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Attachment.class);
  }

  /**
   * The bundle ID for this item. Services can specify a bundleId to group many items together. They
   * appear under a single top-level item on the device.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bundleId;

  /**
   * A canonical URL pointing to the canonical/high quality version of the data represented by the
   * timeline item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String canonicalUrl;

  /**
   * The time at which this item was created, formatted according to RFC 3339.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime created;

  /**
   * The user or group that created this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Contact creator;

  /**
   * The time that should be displayed when this item is viewed in the timeline, formatted according
   * to RFC 3339. This user's timeline is sorted chronologically on display time, so this will also
   * determine where the item is displayed in the timeline. If not set by the service, the display
   * time defaults to the updated time.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime displayTime;

  /**
   * ETag for this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * HTML content for this item. If both text and html are provided for an item, the html will be
   * rendered in the timeline.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String html;

  /**
   * Additional pages of HTML content associated with this item. If this field is specified, the
   * item will be displayed as a bundle, with the html field as the cover. It is an error to specify
   * this field without specifying the html field.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> htmlPages;

  /**
   * The ID of the timeline item. This is unique within a user's timeline.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * If this item was generated as a reply to another item, this field will be set to the ID of the
   * item being replied to. This can be used to attach a reply to the appropriate conversation or
   * post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String inReplyTo;

  /**
   * Whether this item is a bundle cover.
   *
   * If an item is marked as a bundle cover, it will be the entry point to the bundle of items that
   * have the same bundleId as that item. It will be shown only on the main timeline  not within the
   * opened bundle.
   *
   * On the main timeline, items that are shown are:   - Items that have isBundleCover set to true
   * - Items that do not have a bundleId  In a bundle sub-timeline, items that are shown are:   -
   * Items that have the bundleId in question AND isBundleCover set to false
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isBundleCover;

  /**
   * When true, indicates this item is deleted, and only the ID property is set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isDeleted;

  /**
   * When true, indicates this item is pinned, which means it's grouped alongside "active" items
   * like navigation and hangouts, on the opposite side of the home screen from historical (non-
   * pinned) timeline items.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isPinned;

  /**
   * The type of resource. This is always mirror#timelineItem.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The geographic location associated with this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Location location;

  /**
   * A list of menu items that will be presented to the user when this item is selected in the
   * timeline.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<MenuItem> menuItems;

  static {
    // hack to force ProGuard to consider MenuItem used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(MenuItem.class);
  }

  /**
   * Controls how notifications for this item are presented on the device. If this is missing, no
   * notification will be generated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private NotificationConfig notification;

  /**
   * For pinned items, this determines the order in which the item is displayed in the timeline,
   * with a higher score appearing closer to the clock. Note: setting this field is currently not
   * supported.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer pinScore;

  /**
   * A list of users or groups that this item has been shared with.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Contact> recipients;

  static {
    // hack to force ProGuard to consider Contact used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Contact.class);
  }

  /**
   * A URL that can be used to retrieve this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Opaque string you can use to map a timeline item to data in your own service.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String sourceItemId;

  /**
   * The speakable version of the content of this item. Along with the READ_ALOUD menu item, use
   * this field to provide text that would be clearer when read aloud, or to provide extended
   * information to what is displayed visually on Glass.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String speakableText;

  /**
   * Text content of this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String text;

  /**
   * The title of this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The time at which this item was last modified, formatted according to RFC 3339.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * A list of media attachments associated with this item.
   * The value returned may be {@code null}.
   */
  public java.util.List<Attachment> getAttachments() {
    return attachments;
  }

  /**
   * A list of media attachments associated with this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setAttachments(java.util.List<Attachment> attachments) {
    this.attachments = attachments;
    return this;
  }

  /**
   * The bundle ID for this item. Services can specify a bundleId to group many items together. They
   * appear under a single top-level item on the device.
   * The value returned may be {@code null}.
   */
  public String getBundleId() {
    return bundleId;
  }

  /**
   * The bundle ID for this item. Services can specify a bundleId to group many items together. They
   * appear under a single top-level item on the device.
   * The value set may be {@code null}.
   */
  public TimelineItem setBundleId(String bundleId) {
    this.bundleId = bundleId;
    return this;
  }

  /**
   * A canonical URL pointing to the canonical/high quality version of the data represented by the
   * timeline item.
   * The value returned may be {@code null}.
   */
  public String getCanonicalUrl() {
    return canonicalUrl;
  }

  /**
   * A canonical URL pointing to the canonical/high quality version of the data represented by the
   * timeline item.
   * The value set may be {@code null}.
   */
  public TimelineItem setCanonicalUrl(String canonicalUrl) {
    this.canonicalUrl = canonicalUrl;
    return this;
  }

  /**
   * The time at which this item was created, formatted according to RFC 3339.
   * The value returned may be {@code null}.
   */
  public DateTime getCreated() {
    return created;
  }

  /**
   * The time at which this item was created, formatted according to RFC 3339.
   * The value set may be {@code null}.
   */
  public TimelineItem setCreated(DateTime created) {
    this.created = created;
    return this;
  }

  /**
   * The user or group that created this item.
   * The value returned may be {@code null}.
   */
  public Contact getCreator() {
    return creator;
  }

  /**
   * The user or group that created this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setCreator(Contact creator) {
    this.creator = creator;
    return this;
  }

  /**
   * The time that should be displayed when this item is viewed in the timeline, formatted according
   * to RFC 3339. This user's timeline is sorted chronologically on display time, so this will also
   * determine where the item is displayed in the timeline. If not set by the service, the display
   * time defaults to the updated time.
   * The value returned may be {@code null}.
   */
  public DateTime getDisplayTime() {
    return displayTime;
  }

  /**
   * The time that should be displayed when this item is viewed in the timeline, formatted according
   * to RFC 3339. This user's timeline is sorted chronologically on display time, so this will also
   * determine where the item is displayed in the timeline. If not set by the service, the display
   * time defaults to the updated time.
   * The value set may be {@code null}.
   */
  public TimelineItem setDisplayTime(DateTime displayTime) {
    this.displayTime = displayTime;
    return this;
  }

  /**
   * ETag for this item.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * ETag for this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * HTML content for this item. If both text and html are provided for an item, the html will be
   * rendered in the timeline.
   * The value returned may be {@code null}.
   */
  public String getHtml() {
    return html;
  }

  /**
   * HTML content for this item. If both text and html are provided for an item, the html will be
   * rendered in the timeline.
   * The value set may be {@code null}.
   */
  public TimelineItem setHtml(String html) {
    this.html = html;
    return this;
  }

  /**
   * Additional pages of HTML content associated with this item. If this field is specified, the
   * item will be displayed as a bundle, with the html field as the cover. It is an error to specify
   * this field without specifying the html field.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getHtmlPages() {
    return htmlPages;
  }

  /**
   * Additional pages of HTML content associated with this item. If this field is specified, the
   * item will be displayed as a bundle, with the html field as the cover. It is an error to specify
   * this field without specifying the html field.
   * The value set may be {@code null}.
   */
  public TimelineItem setHtmlPages(java.util.List<String> htmlPages) {
    this.htmlPages = htmlPages;
    return this;
  }

  /**
   * The ID of the timeline item. This is unique within a user's timeline.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID of the timeline item. This is unique within a user's timeline.
   * The value set may be {@code null}.
   */
  public TimelineItem setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * If this item was generated as a reply to another item, this field will be set to the ID of the
   * item being replied to. This can be used to attach a reply to the appropriate conversation or
   * post.
   * The value returned may be {@code null}.
   */
  public String getInReplyTo() {
    return inReplyTo;
  }

  /**
   * If this item was generated as a reply to another item, this field will be set to the ID of the
   * item being replied to. This can be used to attach a reply to the appropriate conversation or
   * post.
   * The value set may be {@code null}.
   */
  public TimelineItem setInReplyTo(String inReplyTo) {
    this.inReplyTo = inReplyTo;
    return this;
  }

  /**
   * Whether this item is a bundle cover.
   *
   * If an item is marked as a bundle cover, it will be the entry point to the bundle of items that
   * have the same bundleId as that item. It will be shown only on the main timeline  not within the
   * opened bundle.
   *
   * On the main timeline, items that are shown are:   - Items that have isBundleCover set to true
   * - Items that do not have a bundleId  In a bundle sub-timeline, items that are shown are:   -
   * Items that have the bundleId in question AND isBundleCover set to false
   * The value returned may be {@code null}.
   */
  public Boolean getIsBundleCover() {
    return isBundleCover;
  }

  /**
   * Whether this item is a bundle cover.
   *
   * If an item is marked as a bundle cover, it will be the entry point to the bundle of items that
   * have the same bundleId as that item. It will be shown only on the main timeline  not within the
   * opened bundle.
   *
   * On the main timeline, items that are shown are:   - Items that have isBundleCover set to true
   * - Items that do not have a bundleId  In a bundle sub-timeline, items that are shown are:   -
   * Items that have the bundleId in question AND isBundleCover set to false
   * The value set may be {@code null}.
   */
  public TimelineItem setIsBundleCover(Boolean isBundleCover) {
    this.isBundleCover = isBundleCover;
    return this;
  }

  /**
   * When true, indicates this item is deleted, and only the ID property is set.
   * The value returned may be {@code null}.
   */
  public Boolean getIsDeleted() {
    return isDeleted;
  }

  /**
   * When true, indicates this item is deleted, and only the ID property is set.
   * The value set may be {@code null}.
   */
  public TimelineItem setIsDeleted(Boolean isDeleted) {
    this.isDeleted = isDeleted;
    return this;
  }

  /**
   * When true, indicates this item is pinned, which means it's grouped alongside "active" items
   * like navigation and hangouts, on the opposite side of the home screen from historical (non-
   * pinned) timeline items.
   * The value returned may be {@code null}.
   */
  public Boolean getIsPinned() {
    return isPinned;
  }

  /**
   * When true, indicates this item is pinned, which means it's grouped alongside "active" items
   * like navigation and hangouts, on the opposite side of the home screen from historical (non-
   * pinned) timeline items.
   * The value set may be {@code null}.
   */
  public TimelineItem setIsPinned(Boolean isPinned) {
    this.isPinned = isPinned;
    return this;
  }

  /**
   * The type of resource. This is always mirror#timelineItem.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of resource. This is always mirror#timelineItem.
   * The value set may be {@code null}.
   */
  public TimelineItem setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The geographic location associated with this item.
   * The value returned may be {@code null}.
   */
  public Location getLocation() {
    return location;
  }

  /**
   * The geographic location associated with this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setLocation(Location location) {
    this.location = location;
    return this;
  }

  /**
   * A list of menu items that will be presented to the user when this item is selected in the
   * timeline.
   * The value returned may be {@code null}.
   */
  public java.util.List<MenuItem> getMenuItems() {
    return menuItems;
  }

  /**
   * A list of menu items that will be presented to the user when this item is selected in the
   * timeline.
   * The value set may be {@code null}.
   */
  public TimelineItem setMenuItems(java.util.List<MenuItem> menuItems) {
    this.menuItems = menuItems;
    return this;
  }

  /**
   * Controls how notifications for this item are presented on the device. If this is missing, no
   * notification will be generated.
   * The value returned may be {@code null}.
   */
  public NotificationConfig getNotification() {
    return notification;
  }

  /**
   * Controls how notifications for this item are presented on the device. If this is missing, no
   * notification will be generated.
   * The value set may be {@code null}.
   */
  public TimelineItem setNotification(NotificationConfig notification) {
    this.notification = notification;
    return this;
  }

  /**
   * For pinned items, this determines the order in which the item is displayed in the timeline,
   * with a higher score appearing closer to the clock. Note: setting this field is currently not
   * supported.
   * The value returned may be {@code null}.
   */
  public Integer getPinScore() {
    return pinScore;
  }

  /**
   * For pinned items, this determines the order in which the item is displayed in the timeline,
   * with a higher score appearing closer to the clock. Note: setting this field is currently not
   * supported.
   * The value set may be {@code null}.
   */
  public TimelineItem setPinScore(Integer pinScore) {
    this.pinScore = pinScore;
    return this;
  }

  /**
   * A list of users or groups that this item has been shared with.
   * The value returned may be {@code null}.
   */
  public java.util.List<Contact> getRecipients() {
    return recipients;
  }

  /**
   * A list of users or groups that this item has been shared with.
   * The value set may be {@code null}.
   */
  public TimelineItem setRecipients(java.util.List<Contact> recipients) {
    this.recipients = recipients;
    return this;
  }

  /**
   * A URL that can be used to retrieve this item.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * A URL that can be used to retrieve this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Opaque string you can use to map a timeline item to data in your own service.
   * The value returned may be {@code null}.
   */
  public String getSourceItemId() {
    return sourceItemId;
  }

  /**
   * Opaque string you can use to map a timeline item to data in your own service.
   * The value set may be {@code null}.
   */
  public TimelineItem setSourceItemId(String sourceItemId) {
    this.sourceItemId = sourceItemId;
    return this;
  }

  /**
   * The speakable version of the content of this item. Along with the READ_ALOUD menu item, use
   * this field to provide text that would be clearer when read aloud, or to provide extended
   * information to what is displayed visually on Glass.
   * The value returned may be {@code null}.
   */
  public String getSpeakableText() {
    return speakableText;
  }

  /**
   * The speakable version of the content of this item. Along with the READ_ALOUD menu item, use
   * this field to provide text that would be clearer when read aloud, or to provide extended
   * information to what is displayed visually on Glass.
   * The value set may be {@code null}.
   */
  public TimelineItem setSpeakableText(String speakableText) {
    this.speakableText = speakableText;
    return this;
  }

  /**
   * Text content of this item.
   * The value returned may be {@code null}.
   */
  public String getText() {
    return text;
  }

  /**
   * Text content of this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setText(String text) {
    this.text = text;
    return this;
  }

  /**
   * The title of this item.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * The time at which this item was last modified, formatted according to RFC 3339.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * The time at which this item was last modified, formatted according to RFC 3339.
   * The value set may be {@code null}.
   */
  public TimelineItem setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

}
